package initialize

import (
	"github.com/caarlos0/env/v8"
	"github.com/joho/godotenv"
	"log"
)

type Config struct {
	MongoHost     string `env:"MONGO_HOST" envDefault:"127.0.0.1"`
	MongoPort     string `env:"MONGO_PORT" envDefault:"27020"`
	MongoUser     string `env:"MONGO_USER" envDefault:"test"`
	MongoPassword string `env:"MONGO_PASSWORD" envDefault:"test"`
	MongoDatabase string `env:"MONGO_DB" envDefault:"admin"`
	MongoAuth     string `env:"MONGO_AUTH" envDefault:"admin"`
	KafkaBrokers  string `env:"KAFKA_BROKERS"`
	KafkaTopic    string `env:"KAFKA_TOPIC"`
	KafkaGroup    string `env:"KAFKA_GROUP" default:"mailnotifier"`
	SmtpApiUrl    string `env:"SMTP_API_URL"`
	SmtpHost      string `env:"SMTP_HOST"`
	SmtpPort      string `env:"SMTP_PORT"`
	SmtpUsername  string `env:"SMTP_UNAME"`
	SmtpPassword  string `env:"SMTP_PASS"`
	SmtpApiKey    string `env:"SMTP_API_KEY"`
	SmtpSender    string `env:"SMTP_SENDER"`
	CustomerURL   string `env:"CUSTOMER_URL"`
	QuizRPCURL    string `env:"QUIZ_RPC_URL"`
}

func LoadConfig() (*Config, error) {
	if err := godotenv.Load(); err != nil {
		log.Print("No .env file found")
	}
	var config Config
	if err := env.Parse(&config); err != nil {
		return nil, err
	}
	return &config, nil
}
